academics

# XMLRésuméLibrary: User Guide

Element Reference | Element Reference | achievement

## Name

academics — Container for information about academic experience

## Synopsis

### Content Model

    (degrees,note?)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `academics` element contains information about a person's academic experience.

### Parents

`academics` may be contained in these elements: `resume`

## See Also

`pubs`, `memberships`.

## Examples

    <academics>
      <degrees>
        <degree>
          <level>Ph.D</level>
          <major>Toothpick Manufacturing</major>
          <institution>Stanford University</institution>
        </degree>
      </degrees>
      <note>
        <para>
          I also have an honorary doctorate in toothpick structural analysis from
          MIT.
        </para>
      </note>
    </academics>

    <academics>
      <degrees>
        <degree>
          <level>BA</level>
          <major>Culinary Psychology</major>
        </degree>
      </degrees>
    </academics>

Element Reference | Element Reference | achievement